summaryrefslogtreecommitdiff
path: root/include/asterisk/options.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/asterisk/options.h')
-rw-r--r--include/asterisk/options.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/include/asterisk/options.h b/include/asterisk/options.h
index 3b639e6b9..c961d9175 100644
--- a/include/asterisk/options.h
+++ b/include/asterisk/options.h
@@ -29,6 +29,8 @@ extern "C" {
#define AST_CACHE_DIR_LEN 512
#define AST_FILENAME_MAX 80
+#define AST_CHANNEL_NAME 80 /*!< Max length of an ast_channel name */
+
/*! \ingroup main_options */
enum ast_option_flags {
@@ -70,7 +72,7 @@ enum ast_option_flags {
AST_OPT_FLAG_DONT_WARN = (1 << 18),
/*! End CDRs before the 'h' extension */
AST_OPT_FLAG_END_CDR_BEFORE_H_EXTEN = (1 << 19),
/*! Use Zaptel Timing for generators if available */
AST_OPT_FLAG_INTERNAL_TIMING = (1 << 20),
/*! Always fork, even if verbose or debug settings are non-zero */
AST_OPT_FLAG_ALWAYS_FORK = (1 << 21),
@@ -139,6 +141,7 @@ extern struct timeval ast_lastreloadtime;
extern pid_t ast_mainpid;
extern char record_cache_dir[AST_CACHE_DIR_LEN];
+extern char dahdi_chan_name[AST_CHANNEL_NAME];
extern int ast_language_is_prefix;
@@ -70,7 +72,7 @@ enum ast_option_flags {
/*! End CDRs before the 'h' extension */
AST_OPT_FLAG_END_CDR_BEFORE_H_EXTEN = (1 << 19),
- /*! Use Zaptel Timing for generators if available */
+ /*! Use DAHDI Timing for generators if available */
AST_OPT_FLAG_INTERNAL_TIMING = (1 << 20),
/*! Always fork, even if verbose or debug settings are non-zero */